@@ -17,13 +17,14 @@ from watchdog.events import FileSystemEvent, FileSystemEventHandler
 from watchdog.observers import Observer
 
 __all__ = [
+    "import_from_file",
+    "add_source_roots",
+    "get_repo_root",
     "dir_name_to_class_name",
+    "get_src_root",
     "render_py_file",
     "render_file",
-    "import_from_file",
     "EnvoError",
-    "Callback",
-    "FilesWatcher",
     "colored",
 ]
 
